Skip to contents

Given a set of event headers found by reading the tsq file, read data into usable time series formats.

TODO: fix for importing multiple frequencies at once

Usage

read_tev(
  path,
  tsq.headers = NULL,
  streams = c("405A", "465A", "560B"),
  wide = T
)

Arguments

path

folder containing TDT data files (*.tsq, *.tev, etc.)

tsq.headers

tsq header information from parse_tsq

streams

which data streams to parse?

wide

return data in a wide format rather than long

tsq.file

tsq file name

tev.file

tev file name

Value

data.table of raw values