Update FiPhA
update_FiPhA.RdUpdate the package by re-installing the latest build from its github branch, optionally updating packages along the way. Skips updating by default if the package was installed locally.
update_FiPhA.RdUpdate the package by re-installing the latest build from its github branch, optionally updating packages along the way. Skips updating by default if the package was installed locally.