Area Under Curve
auc.RdEstimates the area under a given curve using the trapezoidal rule, which is equivalent to the average of a left and right Riemann sum.
auc.RdEstimates the area under a given curve using the trapezoidal rule, which is equivalent to the average of a left and right Riemann sum.