Read raw values contained in tev file using tsq data
read_tev.RdGiven a set of event headers found by reading the tsq file, read data into usable time series formats.
TODO: fix for importing multiple frequencies at once
Usage
read_tev(
path,
tsq.headers = NULL,
streams = c("405A", "465A", "560B"),
wide = T
)